@@ -23,9 +23,7 @@
 #include "contentjobbase.h"
 #include "messagecomposer_export.h"
 
-namespace MessageComposer
-{
-
+namespace MessageComposer {
 class MultipartJobPrivate;
 
 /**
@@ -42,12 +40,11 @@ public:
     void setMultipartSubtype(const QByteArray &subtype);
 
 protected Q_SLOTS:
-    void process() Q_DECL_OVERRIDE;
+    void process() override;
 
 private:
     Q_DECLARE_PRIVATE(MultipartJob)
 };
-
 }
 
 #endif
